==> zio-aws-ec2_2.13-5.17.104.7-sources.jar: zio/aws/ec2/model/DisableEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisableEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse = {
    import DisableEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse
      .wrap(buildAwsValue())
}
object DisableEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value)
      )
    def ebsEncryptionByDefault: Option[Boolean]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Option[Boolean] =
      scala.Option(impl.ebsEncryptionByDefault()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/DisableEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisableEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse = {
    import DisableEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse
      .wrap(buildAwsValue())
}
object DisableEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value)
      )
    def ebsEncryptionByDefault: Optional[Boolean]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ebsEncryptionByDefault())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.DisableEbsEncryptionByDefaultResponse.ReadOnly =
    new Wrapper(impl)
}
